<?php

# HyperB5 Next Generation
# Copyright (C) 2007-2009 HyperB5 Staff
# http://www.hyperb5.info/
#
# Basato (molto!) su HyperTrekNG 1.2 - 2.1.3
# Copyright (C) 2005-2007 HyperTrek-NG Development Team
# http://www.hypertrek.info/
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
# http://www.gnu.org/copyleft/gpl.html
#
# Thanks to MediaWiki for a few lines of code and some ideas:
# Copyright (C) 2003 Brion Vibber <brion@pobox.com>
# http://www.mediawiki.org/

/**
 * Pagina principale
 *
 * Entry point della procedura di visualizzazione.<br>
 * Definisce il simbolo HYPERB5 che consente di proteggere gli altri file 
 * da esecuzioni non volute.<br>
 * Viene analizzato l'URL, sanificato e scomposto nelle varie parti per passare
 * i dati all'oggetto di costruzione della pagina.
 * 
 *  @autore Luigi Rosa <lrosa@hypertrek.info>
 *  @modificato da Stefano Monguzzi <info@hyperb5.info>
 *  @version 0.4.5 20130603
 */
 
// serve per impedire abusi
define('HYPERB5', true);

// variabili di sessione 
session_start();

// misura di sicurezza, probabilmente poco utile, ma non si sa mai
@ini_set( 'allow_url_fopen', 0 );

// Variabili e definizioni globali
require('include/global.php');
require('include/indici.php');

// Dati di accesso al database
require('include/database.php');

// xajax
require('xajax/xajax_core/xajax.inc.php');
$xajax = new xajax();
$xajax->registerFunction("AJAXscriviIndice");
$xajax->registerFunction("AJAXcerca");

// connessioni con le risorse dati
$hb5_db_ro = new mysqli($hb5_db_ro_host, $hb5_db_ro_user, $hb5_db_ro_pass, $hb5_db_ro_database);
if (mysqli_connect_errno()) {
   echo "<html><head><title>HyperB5</title><meta http-equiv='refresh' content='60'></head><body>Sito temporaneamente in fase di manutenzione.</body></html>\n";
   die();
}
$hb5_db_rw = new mysqli($hb5_db_rw_host, $hb5_db_rw_user, $hb5_db_rw_pass, $hb5_db_rw_database);
if (mysqli_connect_errno()) {
   echo "<html><head><title>HyperB5</title><meta http-equiv='refresh' content='60'></head><body>Sito temporaneamente in fase di manutenzione.</body></html>\n";
   die();
}

// id dell'indice da visualizzare - Usa la variabile superglobal $_SESSION
if (isset($_SESSION['ndx'])) {
	$HB5_indice = strtolower(trim(substr($_SESSION['ndx'], 0, 6)));
} else {
	$HB5_indice = 0;
}
if (!is_numeric($HB5_indice)) $HB5_indice = 0;
$_SESSION['ndx'] = $HB5_indice;

// skin da utilizzare, anche questa nella $_SESSION e via
if (isset($_SESSION['skin'])) {
	$skin = strtolower(trim(substr($_SESSION['skin'], 0, 20)));
} else {
	//se non e' settata prendo quella di default
	$q = $hb5_db_ro->query("SELECT dir FROM skin WHERE isdefault='1'");
	// ci dovrebbe essere solamente un record flaggato default
	if ($q->num_rows > 0) {
		$r = $q->fetch_array();
		$skin = $r['dir'];
	} else {
		// non e' una bella cosa se nessun record e' flaggato default!
		$skin = 'standard';
	}
}

// se mi viene richiesto un cambio di skin
if (isset($_POST['skin'])) {
	$sk = strtolower(trim($hb5_db_ro->escape_string(substr($_POST['skin'], 0, 20))));
	// dopo aver sanificato la stringa verifico che esista davvero
	$q = $hb5_db_ro->query("SELECT dir FROM skin WHERE dir='$sk'");
	if ($q->num_rows > 0) {
		$skin = $sk;
	}
}
$_SESSION['skin'] = $skin;

// seleziona il file per l'output (oggetto che genera la pagina)
// da due o tre colonne, in base al setup dello skin
if (is_file('skin/' . $skin . '/skin.php')) {
	require('skin/' . $skin . '/skin.php');
	if ($skintrecolonne == '0') { require('include/output.php'); }
	elseif ($skintrecolonne == '1') { require('include/output_3c.php'); }
	else { require('include/output.php'); }
	if ($skinbarranav == '0') { $barn = '0'; }
	elseif ($skinbarranav == '1') { $barn = '1'; }
	else { $barn = '1'; }
} else {
// non dovrebbe mai mancare il file skin.php!!!
// in ogni caso, se manca il default  due colonne con barra nav. e lo skin torna a quello di default
	require('include/output.php');
	$barn = '1';
	$skin = 'standard';
	$_SESSION['skin'] = $skin;
}

// i valori vengono troncati per sicurezza. 
// il limite impostato corrisponde alla dimensione massima dei campi relativi nel database
// normalizzo pathinfo
if (isset($_SERVER['PATH_INFO'])) {
	$tag = strtolower(trim(substr($_SERVER['PATH_INFO'], 0, 70)));
} else {
	$tag = '';
}
// e tolgo pure il primo carattere che e' uno slash
$tag = substr($tag, 1);
$uri = $hb5_db_rw->escape_string($_SERVER['REQUEST_URI']);
if (isset($_SERVER['HTTP_REFERER'])) {
	$ref = $hb5_db_rw->escape_string($_SERVER['HTTP_REFERER']);
} else {
	$ref = '';
}

// se il tag e' copertina, resetto l'indice e metto come pagina il main
if ('copertina' == $tag) {
	$_SESSION['ndx'] = 0;
	$tag = 'main';
}

// vedo se si applica la ridirezione, altrimenti visualizzo la pagina
$pathquery = $hb5_db_ro->escape_string($tag);
$q = $hb5_db_ro->query("SELECT * FROM ridirezioni WHERE da='$pathquery'");
if ($q->num_rows > 0) {
	$r = $q->fetch_array();
	header("HTTP/1.1 301 Moved Permanently");
	header("Location: http://www.hyperb5.info/index.php/$r[a]");
	//ridirigo ad altra pagina
} else {
	// posso visualizzare
	$oPagina = new hb5_pagina($tag, $uri, $ref, $barn);
	$oPagina->scrivi();
}

?>
